@@ -1690,6 +1690,17 @@ class Blockchain(object):
                 return self.transactions[transaction_hash]
             else:
                 return None
+                
+    def get_transactions(self):
+        """
+        Iterate over all pending transactions as (hash, Transaction object)
+        tuples.
+        
+        """
+        
+        with self.lock:
+            for transaction_hash, transaction in self.transactions.iteritems():
+                yield transaction_hash, transaction
         
         
     def has_transaction(self, transaction_hash):
@@ -1708,13 +1719,12 @@ class Blockchain(object):
     def add_transaction(self, transaction, callback=None):
         """
         Called when someone has a transaction to give to us. Takes the
-        transaction as a string of bytes. Returns True if the transaction is
-        valid, or False if the transaction is invalid or can't be verified (i.e.
-        references non-downloaded blocks). Only transactions that are valid in
+        transaction as a string of bytes. Only transactions that are valid in
         light of currently queued transactions are acepted.
         
         Calls the callback, if specified, with the transaction's hash and its
-        validity (True or False).
+        validity (True or False). If the transaction is not something we are
+        interested in, doesn't call the callback at all.
         
         We don't queue transactions waiting on the blocks they depend on, like
         we do blocks, because it doesn't matter if we miss having one.
@@ -1731,6 +1741,11 @@ class Blockchain(object):
             # Hash the transaction
             transaction_hash = hashlib.sha512(transaction).digest()
             
+            if self.transactions.has_key(transaction_hash):
+                # We already know about this one. Don't bother trying to verify
+                # it. It won't verify twice, and will just produce console spam.
+               return
+            
             if not self.state_available:
                 # We can't trust our stored state, or the transaction_state that
                 # comes from it.
