@@ -218,14 +218,17 @@ class SQLiteDict(DictMixin):
         database.
         
         """
-        
-        # Grab the page size in bytes
-        page_size = self.conn.execute('PRAGMA page_size').fetchone()[0]
-        
-        # Grab the number of pages (both used and free)
-        page_count = self.conn.execute('PRAGMA page_count').fetchone()[0]
-        
-        return page_size * page_count
+        try:
+            # Grab the page size in bytes
+            page_size = self.conn.execute('PRAGMA page_size').fetchone()[0]
+            
+            # Grab the number of pages (both used and free)
+            page_count = self.conn.execute('PRAGMA page_count').fetchone()[0]
+            
+            return page_size * page_count
+        except:
+            # This isn't allowed on some sqlites
+            return 0
             
     def __getitem__(self, key):
         GET_ITEM = 'SELECT value FROM '+self.table+' WHERE key = ?'
